%plot_CCT_distortion
%
% A script to run in conjunction with calib_gui in TOOLBOX_calib to plot
% the distortion models computed by CCT (Camera Calibration Toolbox)
%
close all;
 
[mx,my] = meshgrid(1:nx/20:nx,1:ny/20:ny);
[nnx,nny]=size(mx);
px=reshape(mx',nnx*nny,1);
py=reshape(my',nnx*nny,1);
kk_new=[fc(1) 0 cc(1);0 fc(2) cc(2);0 0 1];
rays=inv(kk_new)*[px';py';ones(1,length(px))];
x=[rays(1,:)./rays(3,:);rays(2,:)./rays(3,:)];

fh1=figure;
xd=apply_distortion(x,kc);
px2=fc(1)*(xd(1,:)+alpha_c*xd(2,:))+cc(1);
py2=fc(2)*xd(2,:)+cc(2);
dX=px2-px';
dY=py2-py';
Q=quiver(px,py,dX,dY);
title1=pwd;
title1=strrep(title1,'_','\_');
title2=strcat('CCT Full Distortion Model');
title3='Arrows originate from observed positions';
title({title2,title3,title1});
line1=sprintf('Principal Point         = (%0.4g, %0.4g)',cc(1),cc(2));
line2=sprintf('Focal Length            = (%0.4g, %0.4g)',fc(1),fc(2));
line3=sprintf('Radial coefficients     = (%0.4g, %0.4g, %0.4g)',kc(1),kc(2),kc(5));
line4=sprintf('Tangential coefficients = (%0.4g, %0.4g)',kc(3),kc(4));
line5=sprintf('+/- [%0.4g, %0.4g]',cc_error(1),cc_error(2));
line6=sprintf('+/- [%0.4g, %0.4g]',fc_error(1),fc_error(2));
line7=sprintf('+/- [%0.4g, %0.4g, %0.4g]',kc_error(1),kc_error(2),kc_error(5));
line8=sprintf('+/- [%0.4g, %0.4g]',kc_error(3),kc_error(4));
line9=sprintf('Pixel error             = [%0.4g, %0.4g]',err_std(1),err_std(2));
hold;
plot(cc(1),cc(2),'o');
plot(nx/2,ny/2,'x');
dR=reshape(sqrt((dX.*dX)+(dY.*dY)),nny,nnx)';
[C,h]=contour(mx,my,dR,'k');
clabel(C,h);
Mean=mean(mean(dR))
Max=max(max(dR))
%
% Enlarge Figure window
%
position=get(fh1,'Position');
position(4)=position(4)*1.1;
set(fh1,'Position',position);
%
% Reset Axis size
%
position=get(gca,'Position');
position(2)=position(2)+position(4)*0.1;
position(4)=position(4)*0.85;
set(gca,'position',position);

axis equal;
axis ij;
hold;
axes('position',[0 0 1 1],'visible','off');
th=text(0.11,0,{line9,line1,line2,line3,line4},'horizontalalignment','left','verticalalignment','bottom');
text(0.9,0.,{line5,line6,line7,line8},'horizontalalignment','right','verticalalignment','bottom');
%set(th,'FontName','fixed');

fh2=figure;
xd=apply_distortion(x,[0 0 kc(3) kc(4) 0]);
px2=fc(1)*(xd(1,:)+alpha_c*xd(2,:))+cc(1);
py2=fc(2)*xd(2,:)+cc(2);
dX=px2-px';
dY=py2-py';
quiver(px,py,dX,dY);
title2=strcat('CCT Tangential Component of the Distortion Model');
title({title2,title3,title1});
hold;
plot(cc(1),cc(2),'o');
plot(nx/2,ny/2,'x');
dR=reshape(sqrt((dX.*dX)+(dY.*dY)),nny,nnx)';
[C,h]=contour(mx,my,dR,'k');
clabel(C,h);
%
% Enlarge Figure window
%
position=get(fh2,'Position');
position(4)=position(4)*1.1;
set(fh2,'Position',position);
%
% Reset Axis size
%
position=get(gca,'Position');
position(2)=position(2)+position(4)*0.1;
position(4)=position(4)*0.85;
set(gca,'position',position);

paperposition=get(fh2,'PaperPosition');
paperposition(4)=7;
set(fh2,'PaperPosition',paperposition);
axis equal;
axis ij;
hold;

hold;
axes('position',[0 0 1 1],'visible','off');
th=text(0.11,0,{line9,line1,line2,line3,line4},'horizontalalignment','left','verticalalignment','bottom');
text(0.9,0.,{line5,line6,line7,line8},'horizontalalignment','right','verticalalignment','bottom');
%set(th,'FontName','fixed');

fh3=figure;
xd=apply_distortion(x,[kc(1) kc(2) 0 0 kc(5)]);
px2=fc(1)*(xd(1,:)+alpha_c*xd(2,:))+cc(1);
py2=fc(2)*xd(2,:)+cc(2);
dX=px2-px';
dY=py2-py';
quiver(px,py,dX,dY);
title2=strcat('CCT Radial Component of the Distortion Model');
title({title2,title3,title1});
hold;
plot(cc(1),cc(2),'o');
plot(nx/2,ny/2,'x');
dR=reshape(sqrt((dX.*dX)+(dY.*dY)),nny,nnx)';
[C,h]=contour(mx,my,dR,'k');
clabel(C,h);
%
% Enlarge Figure window
%
position=get(fh3,'Position');
position(4)=position(4)*1.1;
set(fh3,'Position',position);
%
% Reset Axis size
%
position=get(gca,'Position');
position(2)=position(2)+position(4)*0.1;
position(4)=position(4)*0.85;
set(gca,'position',position);

paperposition=get(fh3,'PaperPosition');
paperposition(4)=7;
set(fh3,'PaperPosition',paperposition);
axis equal;

axis ij;
hold;
axes('position',[0 0 1 1],'visible','off');
th=text(0.11,0,{line9,line1,line2,line3,line4},'horizontalalignment','left','verticalalignment','bottom');
text(0.9,0.,{line5,line6,line7,line8},'horizontalalignment','right','verticalalignment','bottom');
%set(th,'FontName','fixed');
